# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Package(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'package_id': 'str',
        'name': 'str',
        'creation_date': 'datetime',
        'creation_name': 'str',
        'mod_date': 'datetime',
        'mod_name': 'str',
        'version': 'str',
        'download_url': 'str'
    }

    attribute_map = {
        'package_id': 'packageId',
        'name': 'name',
        'creation_date': 'creationDate',
        'creation_name': 'creationName',
        'mod_date': 'modDate',
        'mod_name': 'modName',
        'version': 'version',
        'download_url': 'downloadUrl'
    }

    def __init__(self, package_id=None, name=None, creation_date=None, creation_name=None, mod_date=None, mod_name=None, version=None, download_url=None):  # noqa: E501
        """Package - a model defined in Swagger"""  # noqa: E501

        self._package_id = None
        self._name = None
        self._creation_date = None
        self._creation_name = None
        self._mod_date = None
        self._mod_name = None
        self._version = None
        self._download_url = None
        self.discriminator = None

        if package_id is not None:
            self.package_id = package_id
        if name is not None:
            self.name = name
        if creation_date is not None:
            self.creation_date = creation_date
        if creation_name is not None:
            self.creation_name = creation_name
        if mod_date is not None:
            self.mod_date = mod_date
        if mod_name is not None:
            self.mod_name = mod_name
        if version is not None:
            self.version = version
        if download_url is not None:
            self.download_url = download_url

    @property
    def package_id(self):
        """Gets the package_id of this Package.  # noqa: E501


        :return: The package_id of this Package.  # noqa: E501
        :rtype: str
        """
        return self._package_id

    @package_id.setter
    def package_id(self, package_id):
        """Sets the package_id of this Package.


        :param package_id: The package_id of this Package.  # noqa: E501
        :type: str
        """

        self._package_id = package_id

    @property
    def name(self):
        """Gets the name of this Package.  # noqa: E501


        :return: The name of this Package.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Package.


        :param name: The name of this Package.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def creation_date(self):
        """Gets the creation_date of this Package.  # noqa: E501


        :return: The creation_date of this Package.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this Package.


        :param creation_date: The creation_date of this Package.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def creation_name(self):
        """Gets the creation_name of this Package.  # noqa: E501


        :return: The creation_name of this Package.  # noqa: E501
        :rtype: str
        """
        return self._creation_name

    @creation_name.setter
    def creation_name(self, creation_name):
        """Sets the creation_name of this Package.


        :param creation_name: The creation_name of this Package.  # noqa: E501
        :type: str
        """

        self._creation_name = creation_name

    @property
    def mod_date(self):
        """Gets the mod_date of this Package.  # noqa: E501


        :return: The mod_date of this Package.  # noqa: E501
        :rtype: datetime
        """
        return self._mod_date

    @mod_date.setter
    def mod_date(self, mod_date):
        """Sets the mod_date of this Package.


        :param mod_date: The mod_date of this Package.  # noqa: E501
        :type: datetime
        """

        self._mod_date = mod_date

    @property
    def mod_name(self):
        """Gets the mod_name of this Package.  # noqa: E501


        :return: The mod_name of this Package.  # noqa: E501
        :rtype: str
        """
        return self._mod_name

    @mod_name.setter
    def mod_name(self, mod_name):
        """Sets the mod_name of this Package.


        :param mod_name: The mod_name of this Package.  # noqa: E501
        :type: str
        """

        self._mod_name = mod_name

    @property
    def version(self):
        """Gets the version of this Package.  # noqa: E501


        :return: The version of this Package.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Package.


        :param version: The version of this Package.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def download_url(self):
        """Gets the download_url of this Package.  # noqa: E501


        :return: The download_url of this Package.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this Package.


        :param download_url: The download_url of this Package.  # noqa: E501
        :type: str
        """

        self._download_url = download_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Package, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Package):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
